@@ -108,7 +108,7 @@ def kg_qq_download_by_shareid(shareid, output_dir='.', info_only=False, caption=
 def qq_download(url, output_dir='.', merge=True, info_only=False, **kwargs):
     """"""
 
-    if re.match(r'https?://egame.qq.com/live\?anchorid=(\d+)', url):
+    if re.match(r'https?://(m\.)?egame.qq.com/', url):
         from . import qq_egame
         qq_egame.qq_egame_download(url, output_dir=output_dir, merge=merge, info_only=info_only, **kwargs)
         return
